@@ -17,6 +17,7 @@
 #include "optionsdialog.h"
 #endif
 
+
 class QMenu;
 class QToolBar;
 class QTabWidget;
@@ -29,6 +30,7 @@ class FileBrowser;
 class GraphTab;
 class PathView;
 class Map;
+class MapList;
 
 class GUI : public QMainWindow
 {
@@ -68,6 +70,7 @@ private slots:
 	void showFullscreen(bool show);
 	void showTracks(bool show);
 	void showRoutes(bool show);
+	void loadMap();
 	void clearMapCache();
 	void nextMap();
 	void prevMap();
@@ -95,7 +98,7 @@ private:
 #ifdef Q_WS_MAEMO_5
 	QMenu *_poiMenu;
 	QMenu *_stdMenu;
-	QMenu *_mapMenu;
+	//QMenu *_mapMenu;
 	QAction *_togglePoiMenu;
 	QAction *_toggleMapMenu;
 	void grabZoomKeys(bool grab);
@@ -105,6 +108,7 @@ private:
 #endif
 	typedef QPair<QDate, QDate> DateRange;
 
+	void loadDatums();
 	void loadMaps();
 	void loadPOIs();
 	void closeFiles();
@@ -153,9 +157,11 @@ private:
 	QToolBar *_showToolBar;
 	QToolBar *_navigationToolBar;
 	QMenu *_poiFilesMenu;
+	QMenu *_mapMenu;
 
 	QActionGroup *_fileActionGroup;
 	QActionGroup *_navigationActionGroup;
+	QActionGroup *_mapsActionGroup;
 	QAction *_exitAction;
 	QAction *_keysAction;
 	QAction *_dataSourcesAction;
@@ -173,6 +179,7 @@ private:
 	QAction *_showPOILabelsAction;
 	QAction *_showMapAction;
 	QAction *_fullscreenAction;
+	QAction *_loadMapAction;
 	QAction *_clearMapCacheAction;
 	QAction *_showGraphsAction;
 	QAction *_showGraphGridAction;
@@ -195,10 +202,12 @@ private:
 	QAction *_showWaypointLabelsAction;
 	QAction *_showRouteWaypointsAction;
 	QAction *_openOptionsAction;
+	QAction *_mapsEnd;
 	QList<QAction*> _mapActions;
 	QList<QAction*> _poiFilesActions;
 
-	QSignalMapper *_poiFilesSM;
+	QSignalMapper *_poiFilesSignalMapper;
+	QSignalMapper *_mapsSignalMapper;
 
 	QLabel *_fileNameLabel;
 	QLabel *_distanceLabel;
@@ -209,7 +218,7 @@ private:
 	QList<GraphTab*> _tabs;
 
 	POI *_poi;
-	QList<Map*> _maps;
+	MapList *_ml;
 
 	FileBrowser *_browser;
 	QList<QString> _files;
