@@ -7,9 +7,9 @@ class LatLon : public Projection
 {
 public:
 	virtual QPointF ll2xy(const Coordinates &c) const
-	  {return c.toPointF();}
+	  {return QPointF(c.lon(), c.lat());}
 	virtual Coordinates xy2ll(const QPointF &p) const
-	  {return Coordinates(p);}
+	  {return Coordinates(p.x(), p.y());}
 };
 
 #endif // LATLON_H
