@@ -48,3 +48,9 @@ int str2int(const char *str, int len)
 
 	return res;
 }
+
+QRectF scaled(const QRectF &rect, qreal factor)
+{
+	return QRectF(QPointF(rect.left() * factor, rect.top() * factor),
+	  QSizeF(rect.width() * factor, rect.height() * factor));
+}
