@@ -7,6 +7,7 @@
 
 class ColorBox;
 class StyleComboBox;
+class OddSpinBox;
 class QSpinBox;
 class QDoubleSpinBox;
 class QComboBox;
@@ -22,10 +23,20 @@ struct Options {
 	int graphWidth;
 	bool pathAntiAliasing;
 	bool graphAntiAliasing;
+	// Data
+	int elevationFilter;
+	int speedFilter;
+	int heartRateFilter;
+	int cadenceFilter;
+	int powerFilter;
+	bool outlierEliminate;
+	qreal pauseSpeed;
+	int pauseInterval;
 	// POI
 	int poiRadius;
 	// System
 	bool useOpenGL;
+	int pixmapCache;
 	// Print/Export
 	bool printName;
 	bool printDate;
@@ -50,12 +61,14 @@ public slots:
 
 private:
 	QWidget *createAppearancePage();
+	QWidget *createDataPage();
 	QWidget *createPOIPage();
 	QWidget *createSystemPage();
 	QWidget *createExportPage();
 
 	Options *_options;
 
+	// Appearance
 	ColorBox *_baseColor;
 	QDoubleSpinBox *_colorOffset;
 	QSpinBox *_trackWidth;
@@ -65,8 +78,21 @@ private:
 	QCheckBox *_pathAA;
 	QSpinBox *_graphWidth;
 	QCheckBox *_graphAA;
+	// Data
+	OddSpinBox *_elevationFilter;
+	OddSpinBox *_speedFilter;
+	OddSpinBox *_heartRateFilter;
+	OddSpinBox *_cadenceFilter;
+	OddSpinBox *_powerFilter;
+	QCheckBox *_outlierEliminate;
+	QDoubleSpinBox *_pauseSpeed;
+	QSpinBox *_pauseInterval;
+	// POI
 	QDoubleSpinBox *_poiRadius;
+	// System
+	QSpinBox *_pixmapCache;
 	QCheckBox *_useOpenGL;
+	// Print/Export
 	QCheckBox *_name;
 	QCheckBox *_date;
 	QCheckBox *_distance;
