@@ -3,7 +3,6 @@
 #include "config.h"
 #include "format.h"
 #include "tooltip.h"
-#include "map.h"
 #include "waypointitem.h"
 
 
@@ -46,11 +45,6 @@ WaypointItem::WaypointItem(const Waypoint &waypoint, Map *map,
 	setAcceptHoverEvents(true);
 }
 
-void WaypointItem::setMap(Map *map)
-{
-	setPos(map->ll2xy(_waypoint.coordinates()));
-}
-
 void WaypointItem::updateShape()
 {
 	QPainterPath p;
@@ -109,14 +103,6 @@ void WaypointItem::paint(QPainter *painter,
 */
 }
 
-/*
-void WaypointItem::setScale(qreal scale)
-{
-	QPointF p = _map->ll2xy(_waypoint.coordinates());
-	setPos(QPointF(p.x(), -p.y()) * scale);
-}
-*/
-
 void WaypointItem::setUnits(enum Units units)
 {
 	setToolTip(toolTip(units));
